from .core import process

ALL = \
{
	'agile_innovative.blinkstick': 'chroma_feedback.consumer.agile_innovative.blinkstick',
	'compulab.fit_statusb': 'chroma_feedback.consumer.compulab.fit_statusb',
	'elgato.streamdeck': 'chroma_feedback.consumer.elgato.streamdeck',
	'embrava.blynclight': 'chroma_feedback.consumer.embrava.blynclight',
	'embrava.blynclight_mini': 'chroma_feedback.consumer.embrava.blynclight_mini',
	'embrava.blynclight_plus': 'chroma_feedback.consumer.embrava.blynclight_plus',
	'gigabyte.rgb_fusion2': 'chroma_feedback.consumer.gigabyte.rgb_fusion2',
	'kuando.busylight_alpha': 'chroma_feedback.consumer.kuando.busylight_alpha',
	'kuando.busylight_omega': 'chroma_feedback.consumer.kuando.busylight_omega',
	'lifx': 'chroma_feedback.consumer.lifx.lifx',
	'luxafor.flag': 'chroma_feedback.consumer.luxafor.flag',
	'luxafor.mute': 'chroma_feedback.consumer.luxafor.mute',
	'luxafor.orb': 'chroma_feedback.consumer.luxafor.orb',
	'magic.hue': 'chroma_feedback.consumer.magic.hue',
	'muteme': 'chroma_feedback.consumer.muteme.muteme',
	'muteme.muteme_mini': 'chroma_feedback.consumer.muteme.muteme_mini',
	'mutesync': 'chroma_feedback.consumer.mutesync.mutesync',
	'nanoleaf': 'chroma_feedback.consumer.nanoleaf.nanoleaf',
	'philips.hue': 'chroma_feedback.consumer.philips.hue',
	'plantronics.status_indicator': 'chroma_feedback.consumer.plantronics.status_indicator',
	'razer.chroma': 'chroma_feedback.consumer.razer.chroma',
	'signify.wiz': 'chroma_feedback.consumer.signify.wiz',
	'thingm.blink1': 'chroma_feedback.consumer.thingm.blink1',
	'xiaomi.yeelight': 'chroma_feedback.consumer.xiaomi.yeelight'
}
